.. :changelog:

History
=========

0.2.0 (2015-04-25)
+++++++++++++++++++
* Development: https://github.com/westurner/pyrpo/commits/develop
* Master: https://github.com/westurner/pyrpo/commits/master

0.1.0 (2014-05-12)
++++++++++++++++++
* First release on PyPI.
* Re-packaged from https://github.com/westurner/dotfiles/blob/2813e4ad/scripts/repos.py
